..
  This file is generated by setup.py

Read fluorescence correlation spectroscopy (FCS) data files
===========================================================

Fcsfiles is a Python library to read Carl Zeiss(r) ConfoCor(r) RAW and ASCII
measurement data files.

:Author: `Christoph Gohlke <https://www.cgohlke.com>`_
:License: BSD-3-Clause
:Version: 2025.12.12
:DOI: `10.5281/zenodo.17905094 <https://doi.org/10.5281/zenodo.17905094>`_

Quickstart
----------

Install the fcsfiles package and all dependencies from the
`Python Package Index <https://pypi.org/project/fcsfiles/>`_::

    python -m pip install -U fcsfiles

See `Examples`_ for using the programming interface.

Source code and support are available on
`GitHub <https://github.com/cgohlke/fcsfiles>`_.

Requirements
------------

This revision was tested with the following requirements and dependencies
(other versions may work):

- `CPython <https://www.python.org>`_ 3.11.9, 3.12.8, 3.13.11, 3.14.2 64-bit
- `NumPy <https://pypi.org/project/numpy/>`_ 2.3.5

Revisions
---------

2025.12.12

- Drop support for Python 3.10, support Python 3.14.

2025.1.1

- Improve type hints.
- Drop support for Python 3.9, support Python 3.13.

2024.5.24

- Support NumPy 2.
- Fix docstring examples not correctly rendered on GitHub.

2023.8.30

- Fix linting issues.
- Add py.typed marker.
- Convert to Google style docstrings.
- Drop support for Python 3.8 and numpy < 1.22 (NEP29).

2022.9.28

- Update metadata.

2022.2.2

- Add type hints.
- Use float64 or int64 for ConfoCor3Fcs arrays.
- Drop support for Python 3.7 and numpy < 1.19 (NEP29).

2021.6.6

- Drop support for Python 3.6 (NEP 29).

2020.9.18

- Relax ConfoCor3Raw header requirement.
- Support os.PathLike file names.

2020.1.1

- Drop support for Python 2.7 and 3.5.

Notes
-----

"Carl Zeiss" and "ConfoCor" are registered trademarks of Carl Zeiss, Inc.

The use of this implementation may be subject to patent or license
restrictions.

The API is not stable yet and is expected to change between revisions.

This module does *not* read flow cytometry standard FCS files.

Examples
--------

Read the CountRateArray from a ConfoCor3 ASCII file as a numpy array:

.. code-block:: python

    >>> fcs = ConfoCor3Fcs('ConfoCor3.fcs')
    >>> fcs['FcsData']['FcsEntry'][0]['FcsDataSet']['CountRateArray'].shape
    (60000, 2)
    >>> print(fcs)  # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
    Carl Zeiss ConfoCor3 - measurement data file - version 3.0 ANSI
    BEGIN FcsData 30000
            Name = Fluorescein
            Comment =
            AverageFlags = Repeat|Position|Average_Fit_Results
            SortOrder = Channel-Repeat-Position-Kinetics
            BEGIN FcsEntry1 10000
    ...

Read data and metadata from a ConfoCor3 RAW file:

.. code-block:: python

    >>> fcs = ConfoCor3Raw('ConfoCor3.raw')
    >>> fcs.filename
    'f5ee4f36488fca2f89cb6b8626111006_R1_P1_K1_Ch1.raw'
    >>> fcs.frequency
    20000000
    >>> times = fcs.asarray()
    >>> int(times[10858])
    1199925494
    >>> times, bincounts = fcs.asarray(bins=1000)
    >>> times.shape
    (1000,)
    >>> int(bincounts[618])
    23
    >>> fcs.close()

Read data and metadata from a ConfoCor2 RAW file:

.. code-block:: python

    >>> fcs = ConfoCor2Raw('ConfoCor2.raw')
    >>> fcs.frequency
    20000000
    >>> ch0, ch1 = fcs.asarray()
    >>> int(ch1[4812432])
    999999833
    >>> times, ch0, ch1 = fcs.asarray(bins=1000)
    >>> times.shape
    (1000,)
    >>> int(ch1[428])
    10095
    >>> fcs.close()